Module amplitudes

Module amplitudes 

Structs

PyCompiledExpression
A class which can be used to display the compiled form of an Expression
PyEvaluator
A class which can be used to evaluate a stored Expression
PyExpression
A mathematical expression formed from amplitudes.
PyParameter
PyParameterMap

Enums

PyKopfKMatrixA0Channel
PyKopfKMatrixA2Channel
PyKopfKMatrixF0Channel
PyKopfKMatrixF2Channel
PyKopfKMatrixPi1Channel
PyKopfKMatrixRhoChannel

Functions

py_blatt_weisskopf
Construct a Blatt-Weisskopf amplitude.
py_breit_wigner
Construct a relativistic Breit-Wigner amplitude.
py_breit_wigner_non_relativistic
Construct a non-relativistic Breit-Wigner amplitude.
py_clebsch_gordan
Construct a Clebsch-Gordan constant expression.
py_complex_scalar
Construct a cartesian complex scalar amplitude.
py_expr_one
A convenience class representing a unit-valued Expression
py_expr_product
A convenience method to multiply sequences of Expressions
py_expr_sum
A convenience method to sum sequences of Expressions
py_expr_zero
A convenience class representing a zero-valued Expression
py_flatte
Construct a Flatte amplitude.
py_kopf_kmatrix_a0
Construct the fixed Kopf a0 K-matrix amplitude.
py_kopf_kmatrix_a2
Construct the fixed Kopf a2 K-matrix amplitude.
py_kopf_kmatrix_f0
Construct the fixed Kopf f0 K-matrix amplitude.
py_kopf_kmatrix_f2
Construct the fixed Kopf f2 K-matrix amplitude.
py_kopf_kmatrix_pi1
Construct the fixed Kopf pi1 K-matrix amplitude.
py_kopf_kmatrix_rho
Construct the fixed Kopf rho K-matrix amplitude.
py_lookup_table
Construct a fixed-complex lookup table amplitude.
py_lookup_table_complex
Construct a cartesian-complex lookup table amplitude.
py_lookup_table_polar
Construct a polar-complex lookup table amplitude.
py_lookup_table_scalar
Construct a scalar-parameter lookup table amplitude.
py_parameter
A free parameter which floats during an optimization
py_phase_space_factor
Construct a phase-space factor amplitude.
py_photon_sdme
Construct a photon SDME amplitude.
py_polar_complex_scalar
Construct a polar complex scalar amplitude.
py_polphase
Construct a polarization phase amplitude.
py_scalar
Construct a scalar amplitude from one parameter.
py_test_amplitude
An amplitude used only for internal testing which evaluates (p0 + i * p1) * event.p4s\[0\].e.
py_variable_scalar
Construct a real expression from an event variable.
py_voigt
Construct a Voigt amplitude.
py_wigner_3j
Construct a Wigner-3j constant expression.
py_wigner_d
Construct a Wigner-D amplitude.
py_ylm
Construct a spherical-harmonic amplitude.
py_zlm
Construct a polarized spherical-harmonic amplitude.