py_parameter

Function py_parameter 

pub fn py_parameter(
    name: &str,
    fixed: Option<f64>,
    initial: Option<f64>,
    bounds: (Option<f64>, Option<f64>),
    unit: Option<&str>,
    latex: Option<&str>,
    description: Option<&str>,
) -> PyParameter
A free parameter which floats during an optimization

Parameters

name : str The name of the free parameter fixed : float, optional If specified, the parameter will be fixed to this value initial : float, optional If specified, the parameter will always be initialized to this value bounds : tuple of (float or None, float or None) Specify the lower and upper bounds for the parameter (None corresponds to no bound) unit : str, optional Optional unit string which may be used to annotate the parameter latex : str, optional Optional LaTeX representation of the parameter description : str, optional Optional description of the parameter

Returns

laddu.Parameter An object that can be used as the input for many Amplitude constructors

Notes

Two free parameters with the same name are shared in a fit.

Attempting to set both the fixed and initial value will result in an overwrite (both will be set to the “fixed” value).