Module data

Module data 

Structs

PyBinnedDataset
A collection of Datasets binned by a Variable
PyDatasetEventsGlobalIter
PyDatasetEventsLocalIter
PyEvent
A single event
PyParquetBatchWriter
Streaming writer for appending compatible Dataset batches to one Parquet file.
PyParquetChunkIter

Functions

open_parquet_writer
Open a streaming Parquet writer for compatible Dataset batches.
read_parquet
Read a Dataset from a Parquet file.
read_parquet_chunked
Read a Dataset from a Parquet file in chunks.
read_root
Read a Dataset from a ROOT file using the oxyroot backend.
write_parquet
Write a Dataset to a Parquet file.
write_root
Write a Dataset to a ROOT file using the oxyroot backend.