PyDataset

Struct PyDataset 

pub struct PyDataset(pub Arc<Dataset>);
A set of Events

Datasets can be created from lists of Events or by using the constructor helpers such as :func:laddu.io.read_parquet, :func:laddu.io.read_root, and :func:laddu.io.read_amptools

Datasets can also be indexed directly to access individual Events

Parameters

events : list of Event p4_names : list of str, optional Names assigned to each four-momentum; enables name-based lookups if provided. aux_names : list of str, optional Names for auxiliary scalars stored alongside the events. aliases : dict of {str: str or liststr}, optional Additional particle identifiers that override aliases stored on the Events.

Notes

Explicit metadata provided here takes precedence over metadata embedded in the input Events.

Examples

from laddu import Dataset, Event, Vec3 # doctest: +SKIP event = Event( # doctest: +SKIP … [Vec3(0.0, 0.0, 1.0).with_mass(0.0), Vec3(0.0, 0.0, -1.0).with_mass(0.938)], … [0.4, 0.3], … 1.0, … ) dataset = Dataset( # doctest: +SKIP … [event], … p4_names=[‘beam’, ‘proton’], … aux_names=[‘pol_magnitude’, ‘pol_angle’], … aliases={‘target’: ‘proton’}, … ) dataset[0].p4(‘target’) # doctest: +SKIP Vec4(px=0.0, py=0.0, pz=-1.0, e=1.371073…)

Tuple Fields

0: Arc<Dataset>

Implementations

Source

impl PyDataset

pub fn filter(&self, expression: &PyVariableExpression) -> PyResult<PyDataset>

Filter the Dataset by a given VariableExpression, selecting events for which the expression returns True.

Parameters

expression : VariableExpression The expression with which to filter the Dataset

Returns

Dataset The filtered Dataset

Examples

from laddu.utils.variables import Mass # doctest: +SKIP heavy = dataset.filter(Mass([‘kshort1’]) > 1.0) # doctest: +SKIP

pub fn boost_to_rest_frame_of(&self, names: Vec<String>) -> PyDataset

Boost all the four-momenta in all events to the rest frame of the given set of named four-momenta.

Parameters

names : list of str The names of the four-momenta defining the rest frame

Returns

Dataset The boosted dataset

Examples

dataset.boost_to_rest_frame_of([‘kshort1’, ‘kshort2’]) # doctest: +SKIP