Module callbacks

Module callbacks 

Structs

MCMCObserver
An Observer which can be used to monitor the progress of an MCMC algorithm.
MCMCTerminator
A Terminator which can be used to monitor the progress of an MCMC algorithm.
MinimizationObserver
An Observer which can be used to monitor the progress of a minimization.
MinimizationTerminator
An Terminator which can be used to monitor the progress of a minimization.

Enums

PyControlFlow
An enum used by a terminator to continue or stop an algorithm.

Functions

py_integrated_autocorrelation_times
Calculate the integrated autocorrelation time for each parameter according to Karamanis & Beutler (2021).