pub struct MCMCObserver(/* private fields */);Expand description
An Observer which can be used to monitor the progress of an MCMC algorithm.
This should be paired with a Python object which has an observe method
that takes the current step and a ganesh.EnsembleStatus object.