pub struct MCMCTerminator(/* private fields */);Expand description
A Terminator which can be used to monitor the progress of an MCMC algorithm.
This should be paired with a Python object which has an check_for_termination method
that takes the current step and a ganesh.EnsembleStatus object and returns a
PyControlFlow.