pub struct MinimizationObserver(/* private fields */);Expand description
An Observer which can be used to monitor the progress of a minimization.
This should be paired with a Python object which has an observe method
that takes the current step and a method-specific minimization status object.