pub struct MinimizationTerminator(/* private fields */);Expand description
An Terminator which can be used to monitor the progress of a minimization.
This should be paired with a Python object which has an check_for_termination method
that takes the current step and a method-specific minimization status object and returns a
PyControlFlow.