Functions
- py_
binned_ guide_ term - A χ²-like term which uses a known binned result to guide the fit
- py_
regularizer - An weighted :math:
\ell_pregularization term which acts as a maximum a posteriori (MAP) prior.
\ell_p regularization term which acts as a maximum a posteriori (MAP) prior.