pub struct PyGeneratedEventLayout(pub GeneratedEventLayout);Expand description
Metadata describing the columns in a generated event batch.
Tuple Fields
0: GeneratedEventLayoutTrait Implementations
Sourceimpl Clone for PyGeneratedEventLayout
impl Clone for PyGeneratedEventLayout
Sourcefn clone(&self) -> PyGeneratedEventLayout
fn clone(&self) -> PyGeneratedEventLayout
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PyGeneratedEventLayout
impl Debug for PyGeneratedEventLayout
Sourceimpl<'a, 'py> FromPyObject<'a, 'py> for PyGeneratedEventLayoutwhere
Self: Clone,
impl<'a, 'py> FromPyObject<'a, 'py> for PyGeneratedEventLayoutwhere
Self: Clone,
Sourceimpl<'py> IntoPyObject<'py> for PyGeneratedEventLayout
impl<'py> IntoPyObject<'py> for PyGeneratedEventLayout
Sourcetype Target = PyGeneratedEventLayout
type Target = PyGeneratedEventLayout
The Python output type
Sourcetype Output = Bound<'py, <PyGeneratedEventLayout as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyGeneratedEventLayout as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for PyGeneratedEventLayout
impl PyClass for PyGeneratedEventLayout
Sourceimpl PyClassImpl for PyGeneratedEventLayout
impl PyClassImpl for PyGeneratedEventLayout
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// Metadata describing the columns in a generated event batch.
const RAW_DOC: &'static CStr = /// Metadata describing the columns in a generated event batch.
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype Layout = <<PyGeneratedEventLayout as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<PyGeneratedEventLayout>
type Layout = <<PyGeneratedEventLayout as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<PyGeneratedEventLayout>
Description of how this class is laid out in memory
Sourcetype ThreadChecker = NoopThreadChecker
type ThreadChecker = NoopThreadChecker
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
Sourcefn dict_offset() -> Option<PyObjectOffset>
fn dict_offset() -> Option<PyObjectOffset>
Used to provide the dictoffset slot
(equivalent to tp_dictoffset)
Sourcefn weaklist_offset() -> Option<PyObjectOffset>
fn weaklist_offset() -> Option<PyObjectOffset>
Used to provide the weaklistoffset slot
(equivalent to tp_weaklistoffset
Sourceimpl PyMethods<PyGeneratedEventLayout> for PyClassImplCollector<PyGeneratedEventLayout>
impl PyMethods<PyGeneratedEventLayout> for PyClassImplCollector<PyGeneratedEventLayout>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PyGeneratedEventLayout
impl PyTypeInfo for PyGeneratedEventLayout
Sourceconst NAME: &str = <Self as ::pyo3::PyClass>::NAME
const NAME: &str = <Self as ::pyo3::PyClass>::NAME
👎Deprecated since 0.28.0:
prefer using ::type_object(py).name() to get the correct runtime value
Class name.
Sourceconst MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
const MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
👎Deprecated since 0.28.0:
prefer using ::type_object(py).module() to get the correct runtime value
Module name, if any.
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
impl DerefToPyAny for PyGeneratedEventLayout