pub struct PyGeneratedVertexLayout(pub GeneratedVertexLayout);Expand description
Metadata for one generated vertex in a generated event layout.
Tuple Fields
0: GeneratedVertexLayoutTrait Implementations
Sourceimpl Clone for PyGeneratedVertexLayout
impl Clone for PyGeneratedVertexLayout
Sourcefn clone(&self) -> PyGeneratedVertexLayout
fn clone(&self) -> PyGeneratedVertexLayout
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PyGeneratedVertexLayout
impl Debug for PyGeneratedVertexLayout
Sourceimpl<'a, 'py> FromPyObject<'a, 'py> for PyGeneratedVertexLayoutwhere
Self: Clone,
impl<'a, 'py> FromPyObject<'a, 'py> for PyGeneratedVertexLayoutwhere
Self: Clone,
Sourceimpl<'py> IntoPyObject<'py> for PyGeneratedVertexLayout
impl<'py> IntoPyObject<'py> for PyGeneratedVertexLayout
Sourcetype Target = PyGeneratedVertexLayout
type Target = PyGeneratedVertexLayout
The Python output type
Sourcetype Output = Bound<'py, <PyGeneratedVertexLayout as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyGeneratedVertexLayout as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for PyGeneratedVertexLayout
impl PyClass for PyGeneratedVertexLayout
Sourceimpl PyClassImpl for PyGeneratedVertexLayout
impl PyClassImpl for PyGeneratedVertexLayout
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// Metadata for one generated vertex in a generated event layout.
const RAW_DOC: &'static CStr = /// Metadata for one generated vertex in a generated event layout.
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype Layout = <<PyGeneratedVertexLayout as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<PyGeneratedVertexLayout>
type Layout = <<PyGeneratedVertexLayout as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<PyGeneratedVertexLayout>
Description of how this class is laid out in memory
Sourcetype ThreadChecker = NoopThreadChecker
type ThreadChecker = NoopThreadChecker
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
Sourcefn dict_offset() -> Option<PyObjectOffset>
fn dict_offset() -> Option<PyObjectOffset>
Used to provide the dictoffset slot
(equivalent to tp_dictoffset)
Sourcefn weaklist_offset() -> Option<PyObjectOffset>
fn weaklist_offset() -> Option<PyObjectOffset>
Used to provide the weaklistoffset slot
(equivalent to tp_weaklistoffset
Sourceimpl PyMethods<PyGeneratedVertexLayout> for PyClassImplCollector<PyGeneratedVertexLayout>
impl PyMethods<PyGeneratedVertexLayout> for PyClassImplCollector<PyGeneratedVertexLayout>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PyGeneratedVertexLayout
impl PyTypeInfo for PyGeneratedVertexLayout
Sourceconst NAME: &str = <Self as ::pyo3::PyClass>::NAME
const NAME: &str = <Self as ::pyo3::PyClass>::NAME
👎Deprecated since 0.28.0:
prefer using ::type_object(py).name() to get the correct runtime value
Class name.
Sourceconst MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
const MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
👎Deprecated since 0.28.0:
prefer using ::type_object(py).module() to get the correct runtime value
Module name, if any.
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
impl DerefToPyAny for PyGeneratedVertexLayout