pub struct PyAngles(pub Angles);Expand description
A Variable used to define both spherical decay angles in the given frame
This class combines laddu.CosTheta and laddu.Phi into a single
object
Parameters
topology : laddu.Topology
Topology describing the 2-to-2 production kinematics in the center-of-momentum frame.
daughter : list of str
Names of particles which are combined to form one of the decay products of the
resonance associated with k3 of the topology.
frame : {‘Helicity’, ‘HX’, ‘HEL’, ‘GottfriedJackson’, ‘Gottfried Jackson’, ‘GJ’, ‘Gottfried-Jackson’}
The frame to use in the calculation
Raises
ValueError
If frame is not one of the valid options
See Also
laddu.CosTheta laddu.Phi
Tuple Fields
0: AnglesTrait Implementations
Sourceimpl<'py> IntoPyObject<'py> for PyAngles
impl<'py> IntoPyObject<'py> for PyAngles
Sourcetype Output = Bound<'py, <PyAngles as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyAngles as IntoPyObject<'py>>::Target>
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Sourceimpl PyClassImpl for PyAngles
impl PyClassImpl for PyAngles
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
Sourceconst RAW_DOC: &'static CStr = /// A Variable used to define both spherical decay angles in the given frame
///
/// This class combines ``laddu.CosTheta`` and ``laddu.Phi`` into a single
/// object
///
/// Parameters
/// ----------
/// topology : laddu.Topology
/// Topology describing the 2-to-2 production kinematics in the center-of-momentum frame.
/// daughter : list of str
/// Names of particles which are combined to form one of the decay products of the
/// resonance associated with ``k3`` of the topology.
/// frame : {'Helicity', 'HX', 'HEL', 'GottfriedJackson', 'Gottfried Jackson', 'GJ', 'Gottfried-Jackson'}
/// The frame to use in the calculation
///
/// Raises
/// ------
/// ValueError
/// If `frame` is not one of the valid options
///
/// See Also
/// --------
/// laddu.CosTheta
/// laddu.Phi
///
const RAW_DOC: &'static CStr = /// A Variable used to define both spherical decay angles in the given frame /// /// This class combines ``laddu.CosTheta`` and ``laddu.Phi`` into a single /// object /// /// Parameters /// ---------- /// topology : laddu.Topology /// Topology describing the 2-to-2 production kinematics in the center-of-momentum frame. /// daughter : list of str /// Names of particles which are combined to form one of the decay products of the /// resonance associated with ``k3`` of the topology. /// frame : {'Helicity', 'HX', 'HEL', 'GottfriedJackson', 'Gottfried Jackson', 'GJ', 'Gottfried-Jackson'} /// The frame to use in the calculation /// /// Raises /// ------ /// ValueError /// If `frame` is not one of the valid options /// /// See Also /// -------- /// laddu.CosTheta /// laddu.Phi ///
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
text_signature if a constructor is defined. Read moreSourcetype Layout = <<PyAngles as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<PyAngles>
type Layout = <<PyAngles as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<PyAngles>
Sourcetype ThreadChecker = NoopThreadChecker
type ThreadChecker = NoopThreadChecker
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
Sourcefn dict_offset() -> Option<PyObjectOffset>
fn dict_offset() -> Option<PyObjectOffset>
Sourcefn weaklist_offset() -> Option<PyObjectOffset>
fn weaklist_offset() -> Option<PyObjectOffset>
Sourceimpl PyClassNewTextSignature for PyAngles
impl PyClassNewTextSignature for PyAngles
const TEXT_SIGNATURE: &'static str = "(topology, daughter, frame=\"Helicity\")"
Sourceimpl PyMethods<PyAngles> for PyClassImplCollector<PyAngles>
impl PyMethods<PyAngles> for PyClassImplCollector<PyAngles>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PyAngles
impl PyTypeInfo for PyAngles
Sourceconst NAME: &str = <Self as ::pyo3::PyClass>::NAME
const NAME: &str = <Self as ::pyo3::PyClass>::NAME
prefer using ::type_object(py).name() to get the correct runtime value
Sourceconst MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
const MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
prefer using ::type_object(py).module() to get the correct runtime value
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
impl DerefToPyAny for PyAngles