Skip to main contentModule variables
Source - PyAngles
- A Variable used to define both spherical decay angles in the given frame
- PyCosTheta
- The cosine of the polar decay angle in the rest frame of the given
resonance - PyDecay
- A reaction-aware isobar decay view.
- PyMandelstam
- Mandelstam variables s, t, and u
- PyMass
- The invariant mass of an arbitrary combination of constituent particles in an Event
- PyParticle
- A kinematic particle used to define reaction-aware variables.
- PyPhi
- The aziumuthal decay angle in the rest frame of the given
resonance - PyPolAngle
- The polar angle of the given polarization vector with respect to the production plane
- PyPolMagnitude
- The magnitude of the given particle’s polarization vector
- PyPolarization
- A Variable used to define both the polarization angle and magnitude of the given particle``
- PyReaction
- A reaction topology with direct particle definitions.
- PyVariableExpression
- PyP4SelectionInput
- PyVariable