Module experimental

Module experimental 

Functions

py_binned_guide_term
A χ²-like term which uses a known binned result to guide the fit
py_regularizer
An weighted :math:\ell_p regularization term which acts as a maximum a posteriori (MAP) prior.